Index: CMakeLists.txt
==================================================================
--- CMakeLists.txt
+++ CMakeLists.txt
@@ -18,10 +18,11 @@
 option(WITH_LIBMAD     "Enable MP3 support via libmad (if off, dr_mp3 will be used)" OFF)
 option(WITH_SYS_FLAC   "Enable FLAC support via libflac (if off, dr_flac will be used)" OFF)
 option(WITH_FLUID      "Enable FluidSynth support" ON)
 option(WITH_LIBJIT     "Enable LibJIT support in VavoomC compiler (don't use!)" OFF)
 option(WITH_XRANDR     "Enable XRandR support for DPI detection (don't use!)" OFF)
+option(WITH_WNT64      "Enable 64-bit build" OFF)
 if(WIN32)
 option(WITH_SYS_FLUID  "Use system FluidSynth library" OFF)
 else(WIN32)
 option(WITH_SYS_FLUID  "Use system FluidSynth library" ON)
 endif(WIN32)
@@ -137,10 +138,17 @@
   message(STATUS "Turning off SSE and mi-malloc")
   set(NO_SSE ON)
   set(WITH_MIMALLOC OFF)
 endif()
 
+set( RES_FLAGS -Fpe-i386 )
+
+if (WITH_WNT64)
+    message(STATUS "*** 64-bit builds are UNSUPPORTED ***")
+    add_definitions(-DSTK_TIMET_FIX)
+    set( RES_FLAGS -Fpe-x86-64 )
+endif ()
 
 set(K8_UNFUCK_AS_GCC ON)
 set(K8_UNFUCK_AS_SHITLANG OFF)
 if(NOT CMAKE_COMPILER_IS_GNUCC)
   if (APPLE OR CMAKE_HOST_APPLE OR XCODE_VERSION)
@@ -259,10 +267,12 @@
     #set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -lSDL2main -lSDL2")
     set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -lSDL2")
     add_definitions(-DVAVOOM_ARCH_LINUX_SPECIAL_SDL=1)
   endif(HAVE_SDL2_SUBDIR)
 endif(NOT SDL2_OVERRIDE)
+
+add_definitions(-DSDL_MAIN_HANDLED)
 
 
 set(UNFUCK_GCC_FLAGS "")
 set(UNFUCK_GXX_FLAGS "")
 

Index: libs/vavoomc/vc_object_common.cpp
==================================================================
--- libs/vavoomc/vc_object_common.cpp
+++ libs/vavoomc/vc_object_common.cpp
@@ -1815,11 +1815,16 @@
   vobjGetParam(tmres, tvin);
   timeval tv;
   tv.tv_sec = (((uint64_t)tvin->secs)&0xffffffff)|(((uint64_t)tvin->secshi)<<32);
   //tv.tv_usec = tvin->usecs;
   tm ctm;
+#ifndef STK_TIMET_FIX
   if (localtime_r(&tv.tv_sec, &ctm)) {
+#else
+  time_t tsec = tv.tv_sec;
+  if (localtime_r(&tsec, &ctm)) {
+#endif
     tmres->sec = ctm.tm_sec;
     tmres->min = ctm.tm_min;
     tmres->hour = ctm.tm_hour;
     tmres->month = ctm.tm_mon;
     tmres->year = ctm.tm_year+1900;

Index: source/CMakeLists.txt
==================================================================
--- source/CMakeLists.txt
+++ source/CMakeLists.txt
@@ -732,11 +732,11 @@
     # of source files
     set(RC_SRC ${CMAKE_SOURCE_DIR}/branding/shitdoze.rc)
     set(RC_OBJ ${CMAKE_CURRENT_BINARY_DIR}/shitdoze.o)
     add_custom_command(OUTPUT ${RC_OBJ}
       DEPENDS ${RC_SRC}
-      COMMAND windres -o ${RC_OBJ} -i ${RC_SRC} -Fpe-i386
+      COMMAND windres -o ${RC_OBJ} -i ${RC_SRC} ${RES_FLAGS}
     )
     set(MAIN_SOURCES ${MAIN_SOURCES} ${RC_OBJ})
   endif(WIN32)
 
 

Index: source/server/sv_save.cpp
==================================================================
--- source/server/sv_save.cpp
+++ source/server/sv_save.cpp
@@ -809,11 +809,16 @@
 static VStr TimeVal2Str (const TTimeVal *tvin, bool forAutosave=false) {
   timeval tv;
   tv.tv_sec = (((uint64_t)tvin->secs)&0xffffffff)|(((uint64_t)tvin->secshi)<<32);
   //tv.tv_usec = tvin->usecs;
   tm ctm;
+#ifndef STK_TIMET_FIX
   if (localtime_r(&tv.tv_sec, &ctm)) {
+#else
+  time_t tsec = tv.tv_sec;
+  if (localtime_r(&tsec, &ctm)) {
+#endif
     if (forAutosave) {
       // for autosave
       return VStr(va("%02d:%02d", (int)ctm.tm_hour, (int)ctm.tm_min));
     } else {
       // full

